@@ -3,8 +3,8 @@
 #' Tokenization, Parts of Speech Tagging, Lemmatization and Dependency Parsing or a combination of those. \cr
 #' 
 #' This function allows you to build models based on data in in CONLL-U format
-#' as described at \url{http://universaldependencies.org/format.html}. At the time of writing open data in CONLL-U
-#' format for 50 languages are available at \url{http://universaldependencies.org/#ud-treebanks}. 
+#' as described at \url{https://universaldependencies.org/format.html}. At the time of writing open data in CONLL-U
+#' format for more than 50 languages are available at \url{https://universaldependencies.org}. 
 #' Most of these are distributed under the CC-BY-SA licence or the CC-BY-NC-SA license. \cr
 #' 
 #' This function allows to build annotation tagger models based on these data in CONLL-U format, allowing you 
@@ -16,17 +16,17 @@
 #' @param files_conllu_holdout a character vector of files in CONLL-U format used for holdout evalution of the model. This argument is optional.
 #' @param annotation_tokenizer a string containing options for the tokenizer. This can be either 'none' or 'default' or a list 
 #' of options as mentioned in the UDPipe manual. See the vignette \code{vignette("udpipe-train", package = "udpipe")} or
-#' go directly to \url{http://ufal.mff.cuni.cz/udpipe/users-manual#model_training_tokenizer} for a full description of the options
+#' go directly to \url{http://ufal.mff.cuni.cz/udpipe/1/users-manual#model_training_tokenizer} for a full description of the options
 #' or see the examples below.
 #' Defaults to 'default'. If you specify 'none', the model will not be able to perform tokenization.
 #' @param annotation_tagger a string containing options for the pos tagger and lemmatiser. This can be either 'none' or 'default' or a list 
 #' of options as mentioned in the UDPipe manual. See the vignette \code{vignette("udpipe-train", package = "udpipe")} or
-#' go directly to \url{http://ufal.mff.cuni.cz/udpipe/users-manual#model_training_tagger} for a full description of the options
+#' go directly to \url{http://ufal.mff.cuni.cz/udpipe/1/users-manual#model_training_tagger} for a full description of the options
 #' or see the examples below.
 #' Defaults to 'default'. If you specify 'none', the model will not be able to perform POS tagging or lemmatization.
 #' @param annotation_parser a string containing options for the dependency parser.  This can be either 'none' or 'default' or a list 
 #' of options as mentioned in the UDPipe manual. See the vignette \code{vignette("udpipe-train", package = "udpipe")} or
-#' go directly to \url{http://ufal.mff.cuni.cz/udpipe/users-manual#model_training_parser} for a full description of the options
+#' go directly to \url{http://ufal.mff.cuni.cz/udpipe/1/users-manual#model_training_parser} for a full description of the options
 #' or see the examples below.
 #' Defaults to 'default'. If you specify 'none', the model will not be able to perform dependency parsing.
 #' @return A list with elements 
@@ -40,14 +40,14 @@
 #' }
 #' @seealso \code{\link{udpipe_annotation_params}}, \code{\link{udpipe_annotate}}, \code{\link{udpipe_load_model}},
 #' \code{\link{udpipe_accuracy}}
-#' @references \url{http://ufal.mff.cuni.cz/udpipe/users-manual}
+#' @references \url{http://ufal.mff.cuni.cz/udpipe/1/users-manual}
 #' @details 
 #' In order to train a model, you need to provide files which are in CONLL-U format in argument \code{files_conllu_training}. 
 #' This can be a vector of files or just one file. If you do not have your own CONLL-U files, you can download files for your language of 
-#' choice at \url{http://universaldependencies.org/#ud-treebanks}. \cr
+#' choice at \url{https://universaldependencies.org}. \cr
 #' 
 #' At the time of writing open data in CONLL-U
-#' format for 50 languages are available at \url{http://universaldependencies.org/#ud-treebanks}, namely for: 
+#' format for 50 languages are available at \url{https://universaldependencies.org}, namely for: 
 #' ancient_greek, arabic, basque, belarusian, bulgarian, catalan, chinese, coptic, croatian, 
 #' czech, danish, dutch, english, estonian, finnish, french, galician, german, gothic, greek, hebrew, hindi, hungarian, 
 #' indonesian, irish, italian, japanese, kazakh, korean, latin, latvian, lithuanian, norwegian, 
@@ -151,7 +151,7 @@ udpipe_train <- function(file = file.path(getwd(), "my_annotator.udpipe"),
 #' }
 #' @seealso \code{\link{udpipe_load_model}}
 #' @references \url{https://ufal.mff.cuni.cz/udpipe}, 
-#' \url{http://universaldependencies.org/format.html}
+#' \url{https://universaldependencies.org/format.html}
 #' @export
 #' @examples 
 #' model <- udpipe_download_model(language = "dutch-lassysmall")
@@ -240,7 +240,7 @@ udpipe_read_conllu <- function(file){
 #' token_id, token, lemma, upos, xpos, feats, head_token_id, deprel, dep_rel, misc
 #' @return a character string of length 1 containing the data.frame in CONLL-U format. See the example. You can easily save this to disk for processing in other applications.
 #' @export
-#' @references \url{http://universaldependencies.org/format.html}
+#' @references \url{https://universaldependencies.org/format.html}
 #' @examples 
 #' file_conllu <- system.file(package = "udpipe", "dummydata", "traindata.conllu")
 #' x <- udpipe_read_conllu(file_conllu)
@@ -336,3 +336,34 @@ as_word2vec <- function(x){
   x <- c(line1, lines_rest)
   paste(x, collapse = "\n")
 }
+
+
+
+
+#' @title Combine labels and text as used in fasttext
+#' @description Fasttext prepends a label or different labels to text using a special string (__label__).
+#' This function takes a character vector of text and prepends the labels alongside the special string.
+#' @param x a character vector
+#' @param y a character vector of labels or a list of labels. \code{y} should be of the same length as \code{x} 
+#' @param label the string to use to prepend to the label. Defaults to __label__
+#' @return a character vector of text where \code{x} and \code{y} are combined
+#' @export 
+#' @examples 
+#' as_fasttext(x = c("just a bit of txt", "example2", "more txt please", "more"), 
+#'             y = c("pos", "neg", "neg", NA))
+#' as_fasttext(x = c("just a bit of txt", "example2", "more txt please", "more"), 
+#'             y = list(c("ok", "pos"), c("neg", "topic2"), "", NA))
+as_fasttext <- function(x, y, label = "__label__"){
+  if(is.list(y)){
+    targets <- sapply(y, FUN=function(x){
+      if(length(x) == 0 || all(is.na(x))){
+        return(NA_character_)
+      }
+      paste(paste(label, x, sep = ""), collapse = " ") 
+    })
+  }else{
+    targets <- ifelse(is.na(y), NA_character_, paste(label, y, sep = ""))
+  }
+  x <- ifelse(is.na(targets), x, paste(targets, x, sep = " "))
+  x
+}
